/*
 * kernel/power/suspend2_checksum.h
 *
 * Copyright (C) 2006-2007 Nigel Cunningham (nigel at suspend2 net)
 * Copyright (C) 2006 Red Hat, inc.
 *
 * This file is released under the GPLv2.
 *
 * This file contains data checksum routines for Suspend2,
 * using cryptoapi. They are used to locate any modifications
 * made to pageset 2 while we're saving it.
 */

#if defined(CONFIG_TOI_CHECKSUM)
extern int toi_checksum_init(void);
extern void toi_checksum_exit(void);
void check_checksums(void);
int allocate_checksum_pages(void);
void free_checksum_pages(void);
char *suspend2_get_next_checksum(void);
int suspend2_calc_checksum(struct page *page, char *checksum_locn);
#else
static inline int toi_checksum_init(void) { return 0; }
static inline void toi_checksum_exit(void) { }
static inline void check_checksums(void) { };
static inline int allocate_checksum_pages(void) { return 0; };
static inline void free_checksum_pages(void) { };
static inline char *suspend2_get_next_checksum(void) { return NULL; };
static inline int suspend2_calc_checksum(struct page *page, char *checksum_locn)
	{ return 0; }
#endif

